/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */
/*
 * Copyright (c) 2023 Daniel Golle <daniel@makrotopia.org>
 * Author: Daniel Golle <daniel@makrotopia.org>
 */

#ifndef _DT_BINDINGS_RESET_CONTROLLER_MT7988
#define _DT_BINDINGS_RESET_CONTROLLER_MT7988

/* ETHWARP resets */
#define MT7988_ETHWARP_RST_SWITCH		0

/* INFRA resets */
#define MT7988_INFRA_RST0_PEXTP_MAC_SWRST	0
#define MT7988_INFRA_RST1_THERM_CTRL_SWRST	1


#endif  /* _DT_BINDINGS_RESET_CONTROLLER_MT7988 */

