/* SPDX-License-Identifier: (GPL-2.0+ OR MIT) */
/*
 * Copyright (c) 2019 BayLibre, SAS
 * Author: Neil Armstrong <narmstrong@baylibre.com>
 */

#ifndef _DT_BINDINGS_MESON_G12A_POWER_H
#define _DT_BINDINGS_MESON_G12A_POWER_H

#define PWRC_G12A_VPU_ID		0
#define PWRC_G12A_ETH_ID		1
#define PWRC_G12A_NNA_ID		2
#define PWRC_G12A_ISP_ID		3

#endif
