/* SPDX-License-Identifier: GPL-2.0+ */

#ifndef __DT_BINDINGS_CLOCK_BCM6358_H
#define __DT_BINDINGS_CLOCK_BCM6358_H

#define BCM6358_CLK_ENET	4
#define BCM6358_CLK_ADSLPHY	5
#define BCM6358_CLK_PCM		8
#define BCM6358_CLK_SPI		9
#define BCM6358_CLK_USBS	10
#define BCM6358_CLK_SAR		11
#define BCM6358_CLK_EMUSB	17
#define BCM6358_CLK_ENET0	18
#define BCM6358_CLK_ENET1	19
#define BCM6358_CLK_USBSU	20
#define BCM6358_CLK_EPHY	21

#endif /* __DT_BINDINGS_CLOCK_BCM6358_H */
