/* SPDX-License-Identifier: GPL-2.0+ */

#ifndef __DT_BINDINGS_BMIPS_BCM6318_PM_H
#define __DT_BINDINGS_BMIPS_BCM6318_PM_H

#define BCM6318_POWER_DOMAIN_PCIE	0
#define BCM6318_POWER_DOMAIN_USB	1
#define BCM6318_POWER_DOMAIN_EPHY0	2
#define BCM6318_POWER_DOMAIN_EPHY1	3
#define BCM6318_POWER_DOMAIN_EPHY2	4
#define BCM6318_POWER_DOMAIN_EPHY3	5
#define BCM6318_POWER_DOMAIN_LDO2P5	6
#define BCM6318_POWER_DOMAIN_LDO2P9	7
#define BCM6318_POWER_DOMAIN_SW1P0	8
#define BCM6318_POWER_DOMAIN_PAD	9

#endif /* __DT_BINDINGS_BMIPS_BCM6318_PM_H */
